..
    This file is part of Invenio.
    Copyright (C) 2017-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _developers-guide:

Developer's Guide
-----------------
This part of the documentation will show you how to get started developing for
Invenio.

.. toctree::
    :maxdepth: 2
    :name: mastertoc

    tutorial/index
    development-environment
    system-architecture
    application-architecture
    extending-invenio
    invenio-modules
    bundles
    create-a-datamodel
    docker
    git
    python
    testing-practices
